@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # :copyright: (c) 2021 by Pavlo Dmytrenko.
 # :license: MIT, see LICENSE for more details.
 
@@ -10,9 +8,6 @@ yaspin.helpers
 Helper functions.
 """
 
-from __future__ import absolute_import
-
-from .compat import bytes  # pylint: disable=redefined-builtin
 from .constants import ENCODING
 
 
